# @summary Manages the Mining Rigger Client.
#
# @param client_user
#   The username of the client to connect to the server.
#
# @param client_password
#   The user's password to connect to the server.
#
# @param miner
#   The name of the miner used on this rig.
#   Valid Values: trex and kawpowminer
#
# @param minute
#   How often the client should be run to checkin with the server.
#
# @param src_url
#   The URL that contains the source which should be a git repository.
#
# @param version
#   The tag or branch of the git repository that should be deployed.
#
# @param server_url
#   The url to the server
#
# @param python
#   The command to use for running python.
#
class mining_rigger::client (
  String  $server_url,
  String  $client_user,
  String  $client_password,
  String  $miner,
  Integer $minute  = 5,
  String  $src_url = 'git://bitbucket.org/monkygames/miningriggerclient.git',
  String  $version = 'main',
  String  $python  = 'python3',
) {
  # setup shared environment
  include mining_rigger

  $client_cmd = "${mining_rigger::root}/client.bash"

  # setup sensors
  package { 'lm-sensors':
    ensure => installed,
  }

  exec { 'detect_sensors':
    command     => '/usr/sbin/sensors-detect --auto',
    refreshonly => true,
    subscribe   => Package['lm-sensors'],
  }

  # Download the client
  vcsrepo { $mining_rigger::client_root:
    ensure   => latest,
    provider => git,
    user     => $mining_rigger::user,
    source   => $src_url,
    revision => $version,
    require  => Exec['detect_sensors'],
  }

  exec { 'setup_client':
    command     => "${mining_rigger::pipenv} install --ignore-pipfile",
    cwd         => $mining_rigger::client_root,
    user        => $mining_rigger::user,
    subscribe   => Vcsrepo[$mining_rigger::client_root],
    refreshonly => true,
  }

  file { $client_cmd:
    ensure  => file,
    mode    => '0755',
    owner   => $mining_rigger::user,
    group   => $mining_rigger::user,
    content => epp('mining_rigger/client.bash.epp', {
        client_directory => $mining_rigger::client_root,
        pipenv           => $mining_rigger::pipenv,
        python           => $python,
        miner            => $miner,
    }),
    require => Exec['setup_client'],
  }

  cron { 'client_checkin':
    command => "${client_cmd} ${server_url} ${client_user} ${client_password} ${miner}",
    user    => $mining_rigger::user,
    minute  => $minute,
    require => File[$client_cmd],
  }
}
