# @summary Manages the Mining Rigger Server.
#
# @param port
#   The port the server should listen on.
#
# @param src_url
#   The URL that contains the source which should be a git repository.
#
# @param version
#   The tag or branch of the git repository that should be deployed.
#
# @param admin_username
#   The admin user account for the server.
#
# @param admin_password
#   The admin's password.
#
# @param admin_email
#   The email address of the admin.
#
# @param manage_python
#   If true, uses the system packages for installing python and false if this module
#   should not manage python.
#
# @param python
#   The command to use for running python.
#
class mining_rigger::server (
  Integer $port           = 8000,
  String  $src_url        = 'git://bitbucket.org/monkygames/miningriggerserver.git',
  String  $version        = 'main',
  String  $admin_username = 'admin',
  String  $admin_password = 'admin',
  String  $admin_email    = 'nobody@nobody.com',
  Boolean $manage_python  = true,
  String  $python         = 'python3',
) {
  # setup shared environment
  class { 'mining_rigger':
    manage_python => $manage_python,
  }
  contain mining_rigger

  # Download the client
  vcsrepo { $mining_rigger::server_root:
    ensure   => latest,
    provider => git,
    user     => $mining_rigger::user,
    source   => $src_url,
    revision => $version,
  }

  exec { 'setup_server':
    command     => "${mining_rigger::pipenv} install --ignore-pipfile",
    cwd         => $mining_rigger::server_root,
    user        => $mining_rigger::user,
    subscribe   => Vcsrepo[$mining_rigger::server_root],
    refreshonly => true,
  }

  exec { 'setup_database':
    command     => "${mining_rigger::pipenv} run ${python} manage.py makemigrations && 
    ${mining_rigger::pipenv} run ${python} manage.py migrate --run-syncdb",
    cwd         => $mining_rigger::server_root,
    user        => $mining_rigger::user,
    subscribe   => Vcsrepo[$mining_rigger::server_root],
    require     => Exec['setup_server'],
    refreshonly => true,
  }

  exec { 'setup_admin':
    command     => "${mining_rigger::pipenv} run ${python} manage.py createsuperuser --noinput",
    environment => [
      "DJANGO_SUPERUSER_PASSWORD=${admin_password}",
      "DJANGO_SUPERUSER_USERNAME=${admin_username}",
      "DJANGO_SUPERUSER_EMAIL=${admin_email}",
    ],
    cwd         => $mining_rigger::server_root,
    user        => $mining_rigger::user,
    subscribe   => Vcsrepo[$mining_rigger::server_root],
    require     => Exec['setup_database'],
    refreshonly => true,
  }

  systemd::unit_file { 'miningrigger.service':
    active  => true, # if the service should be running
    enable  => true, # if the service should be run after a reboot
    content => epp('mining_rigger/mining-rigger.service.epp',
      {
        user        => $mining_rigger::user,
        root_dir    => $mining_rigger::server_root,
        pipenv      => "${mining_rigger::root}/.local/bin/pipenv",
        description => 'Starts Mining Rigger Server',
        port        => $port,
        python      => $python,
      }
    ),
    require => Exec['setup_server','setup_database'],
  }
}
